@@ -11,10 +11,8 @@ import uuid
 import warnings
 
 # 3rd party library imports
-from osgeo import gdal
 from lxml import etree as ET
 import numpy as np
-from packaging.version import Version
 
 # local imports
 from glymur.jp2box import LabelBox, XMLBox, AssociationBox, UUIDBox
@@ -44,7 +42,9 @@ class TestSuite(fixtures.TestCommon):
 
         uuidinfo = glymur.jp2box.UUIDInfoBox([ulst, debox])
 
-        uuid_data = ir.files("tests.data").joinpath("degenerate_geotiff.tif").read_bytes()  # noqa : E501
+        uuid_data = ir.files("tests.data.tiff") \
+                      .joinpath("degenerate_geotiff.tif") \
+                      .read_bytes()
         the_uuid = uuid.UUID("b14bf8bd-083d-4b43-a5ae-8cd7d5a6ce03")
         geotiff_uuid = glymur.jp2box.UUIDBox(the_uuid, uuid_data)
 
@@ -106,7 +106,9 @@ class TestSuite(fixtures.TestCommon):
         about GDAL not being able to print the UUID data as expected, but that
         is no longer the case.
         """
-        box_data = ir.files("tests.data").joinpath("0220000800_uuid.dat").read_bytes()  # noqa : E501
+        box_data = ir.files("tests.data.geo") \
+                     .joinpath("0220000800_uuid.dat") \
+                     .read_bytes()
         bf = io.BytesIO(box_data)
         bf.seek(8)
         box = UUIDBox.parse(bf, 0, 703)
@@ -190,7 +192,7 @@ class TestSuite(fixtures.TestCommon):
         emitted directly from the TIFF library via GDAL, so they are no longer
         catchable.  No warnings.
         """
-        path = ir.files("tests.data").joinpath("issue398.dat")
+        path = ir.files("tests.data.misc").joinpath("issue398.dat")
         with path.open("rb") as f:
             f.seek(8)
             box = glymur.jp2box.UUIDBox.parse(f, 0, 380)
